pub struct ClientConfig {
pub session_config: SessionConfig,
pub channel_config: ChannelConfig,
pub endpoint: String,
pub environment: Environment,
pub disable_route_to_leader: bool,
pub metrics: MetricsConfig,
}Expand description
ClientConfig has configurations for the client.
Fields
session_config: SessionConfigSessionPoolConfig is the configuration for session pool.
channel_config: ChannelConfigChannelConfig is the configuration for gRPC connection.
endpoint: StringOverriding service endpoint
environment: EnvironmentRuntime project
disable_route_to_leader: boolDisableRouteToLeader specifies if all the requests of type read-write and PDML need to be routed to the leader region.
metrics: MetricsConfigMetrics configuration for emitting OpenTelemetry signals.
Implementations
Sourceimpl ClientConfig
impl ClientConfig
pub async fn with_auth(self) -> Result<Self, Error>
pub async fn with_credentials( self, credentials: CredentialsFile, ) -> Result<Self, Error>