Module mutation

Module mutation 

Functions

delete
delete removes the rows described by the KeySet from the table. It succeeds whether or not the keys were present.
insert
Insert returns a Mutation to insert a row into a table. If the row already exists, the write or transaction fails with codes.AlreadyExists.
insert_map
insert_map returns a Mutation to insert a row into a table, specified by a map of column name to value. If the row already exists, the write or transaction fails with codes.AlreadyExists.
insert_or_update
insert_or_update returns a Mutation to insert a row into a table. If the row already exists, it updates it instead. Any column values not explicitly written are preserved.
insert_or_update_map
insert_or_update returns a Mutation to insert a row into a table. If the row already exists, it updates it instead. Any column values not explicitly written are preserved.
insert_or_update_struct
insert_or_update_struct returns a Mutation to insert a row into a table, specified by a Go struct. If the row already exists, it updates it instead. Any column values not explicitly written are preserved. For a similar example, See update_struct.
insert_struct
insert_struct returns a Mutation to insert a row into a table, specified by a Rust struct. If the row already exists, the write or transaction fails with codes.AlreadyExists.
replace
replace returns a Mutation to insert a row into a table, deleting any existing row. Unlike InsertOrUpdate, this means any values not explicitly written become NULL.
replace_map
replace_map returns a Mutation to insert a row into a table, deleting any existing row. Unlike InsertOrUpdateMap, this means any values not explicitly written become NULL. The row is specified by a map of column to value.
replace_struct
replace_struct returns a Mutation to insert a row into a table, deleting any existing row.
update
update returns a Mutation to update a row in a table. If the row does not already exist, the write or transaction fails.
update_map
update_map returns a Mutation to update a row in a table, specified by a map of column to value. If the row does not already exist, the write or transaction fails.
update_struct
update_struct returns a Mutation to update a row in a table, specified by a Go struct. If the row does not already exist, the write or transaction fails.