BatchReadOnlyTransaction is a ReadOnlyTransaction that allows for exporting
arbitrarily large amounts of data from Cloud Spanner databases.
BatchReadOnlyTransaction partitions a read/query request. Read/query request
can then be executed independently over each partition while observing the
same snapshot of the database.
ReadOnlyTransaction provides a snapshot transaction with guaranteed
consistency across reads, but does not allow writes. Read-only transactions
can be configured to read at timestamps in the past.